package uk.ac.cf.spring.demo.sports.controller;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import uk.ac.cf.spring.demo.sports.user.User;
import uk.ac.cf.spring.demo.sports.user.UserDetail;
import uk.ac.cf.spring.demo.sports.user.UserDetailRepository;
import uk.ac.cf.spring.demo.sports.user.UserRepository;

@Controller
public class UserController {

    @Autowired
    private UserRepository userRepository;

    @Autowired
    private UserDetailRepository userDetailRepository;

    // 显示注册表单
    @GetMapping("/register")
    public String showRegistrationForm(Model model) {
        model.addAttribute("user", new User());
        model.addAttribute("userDetail", new UserDetail());
        return "register";
    }

    // 处理注册请求
    @PostMapping("/register")
    public String registerUser(@ModelAttribute User user, @ModelAttribute UserDetail userDetail, Model model) {
        // 检查用户名是否已存在
        if (userRepository.findByUsername(user.getUsername()) != null) {
            model.addAttribute("error", "Username already exists");
            return "register";
        }

        // 保存用户信息到User表
        User savedUser = userRepository.save(user);

        // 设置user_id为外键，保存UserDetail信息到user_details表
        userDetail.setUser(savedUser);
        userDetailRepository.save(userDetail);

        return "redirect:/success";  // 注册成功后重定向到成功页面
    }

    // 注册成功页面
    @GetMapping("/success")
    public String registrationSuccess() {
        return "success";  // 显示注册成功页面
    }
}
