package uk.ac.cf.spring.demo.sports.match;

import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.servlet.ModelAndView;

import java.util.List;

@Controller
public class MatchController {
    //tell the Springboot that MatchController depend on MatchService
    private final MatchService matchService;
    public MatchController(MatchService aMatchService) {
        this.matchService = aMatchService;
    }
    //    all Match List
    @GetMapping("/match")
    public ModelAndView getMatch() {
        ModelAndView modelAndView = new ModelAndView("match/allMatchList");
        List<MatchItem> matchItems = matchService.getMatchItems();
        modelAndView.addObject("matchItems", matchItems);
        return modelAndView;
    }
    // get match through id
    @GetMapping("/match/{id}")
    public ModelAndView getMatchItem(@PathVariable Long id) {
        ModelAndView modelAndView = new ModelAndView("match/matchDetails");
        MatchItem matchItem = matchService.getMatchItemById(id);
        modelAndView.addObject("matchItem", matchItem);
        return modelAndView;
    }
    //matchItemForm add match
    @GetMapping("/match/add")
    public ModelAndView addMatchItem() {
        ModelAndView modelAndView = new ModelAndView("match/matchItemForm");
        MatchItemForm emptyMatchItem = new MatchItemForm();
        modelAndView.addObject("matchItem", emptyMatchItem);
        return modelAndView;
    }

    //
    @GetMapping("/match/edit/{id}")
    public ModelAndView editMatchItemTh(@PathVariable("id") Long id) {
        ModelAndView modelAndView = new ModelAndView("match/matchItemForm");
        // construct matchToUpdate object to get matchItem by id
        MatchItem matchToUpdate = matchService.getMatchItemById(id);
        // Create the form object for the match
        MatchItemForm matchItemForm = new MatchItemForm(
                matchToUpdate.getId(),
                matchToUpdate.getSport(),
                matchToUpdate.getPlayerAId(),
                matchToUpdate.getPlayerBId(),
                matchToUpdate.getPlanTime(),
                matchToUpdate.getStatus(),
                matchToUpdate.getScoreA(),
                matchToUpdate.getScoreB(),
                matchToUpdate.getConfirmByA(),
                matchToUpdate.getConfirmByB(),
                matchToUpdate.getWinnerId()
        );

        modelAndView.addObject("matchItem", matchItemForm);
        return modelAndView;
    }

}
