package uk.ac.cf.spring.demo.sports.match;

import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;

import java.sql.Timestamp;
import java.util.List;
@Repository
public class MatchRepositoryImpl implements MatchRepository{
//    jdbcTemplate - dependency injection
    private JdbcTemplate jdbc;
    private RowMapper<MatchItem> matchItemMapper;
    public MatchRepositoryImpl(JdbcTemplate aJdbc) {
        this.jdbc = aJdbc;
//        set mapper
        setMatchItemMapper();
    }
    private void setMatchItemMapper() {
        matchItemMapper = (rs, i) -> new MatchItem(
                rs.getLong("id"),
                rs.getString("sport"),
                rs.getLong("player_AId"),
                rs.getLong("player_BId"),
//                localDataTime
                rs.getTimestamp("plan_Time").toLocalDateTime(),
                rs.getString("status"),
                rs.getLong("score_a"),
                rs.getLong("score_b"),
                rs.getBoolean("confirm_a"),
                rs.getBoolean("confirm_b"),
                rs.getLong("winner_id")
        );
    }
    @Override
    public List<MatchItem> getMatchItems() {
//        mariadb select all item
        String sql = "select * from match_item";
        return jdbc.query(sql, matchItemMapper);
    }

    @Override
    public MatchItem getMatchItemById(Long id) {
//        mariadb search item by id
        String sql = "select * from match_item where id = ?";
        return jdbc.queryForObject(sql, matchItemMapper, id);
    }

    @Override
    public List<MatchItem> getMatchItemBySport(String sport) {
        String sql = "select * from match_item where sport = ?";
        return  jdbc.query(sql, matchItemMapper, sport);
    }

    @Override
    public void addMatchItem(MatchItem matchItem) {
        String sql = "insert into match_item (sport, player_AId, player_BId, plan_Time, status, score_a, score_b, confirm_a, confirm_b, winner_id) " +
                "values (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";

        jdbc.update(sql,
                matchItem.getSport(),
                matchItem.getPlayerAId(),
                matchItem.getPlayerBId(),
                Timestamp.valueOf(matchItem.getPlanTime()),
                matchItem.getStatus(),
                matchItem.getScoreA(),
                matchItem.getScoreB(),
                matchItem.getConfirmByA(),
                matchItem.getConfirmByB(),
                matchItem.getWinnerId()
        );
    }
}
